@@ -11,8 +11,6 @@
 
 #include "queue.h"
 
-#define COMHISTORY 10
-
 struct player {
 	struct qelem queue;
 	struct lwpProc *proc;
@@ -25,8 +23,6 @@ struct player {
 	struct comstr *command;
 	struct iop *iop;
 	s_char	combuf[512];
-	s_char	comhistory[COMHISTORY][512]; /* not used */
-	u_char	comhistoff;	/* not used -- index into above array */
 	s_char	*argp[64];
 	s_char	*condarg;
 	long	lasttime;
